..
    This file is part of Invenio.
    Copyright (C) 2017-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


======================
 Invenio-PIDRelations
======================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-pidrelations.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-pidrelations

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-pidrelations.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-pidrelations

.. image:: https://img.shields.io/pypi/v/invenio-pidrelations.svg
        :target: https://pypi.org/pypi/invenio-pidrelations

*This is an experimental developer preview release.*

* Extends InvenioPIDStore with PID relations, allowing for defining
  PID versioning assembling PID collections or defining "Head" PIDs.


Further documentation is available on
https://invenio-pidrelations.readthedocs.io/
